import { CustomStyleRegistry } from '../registries/CustomStyleRegistry.js';
import { ElementRegistry } from '../registries/ElementRegistry.js';
const defaultOptions = {
    theme: true
};
/**
 * Registers a Custom Element
 * into the ELF element registry.
 * Use this instead of `customElements.define`
 * to allow for ELF theming support and telemetry.
 * @param name tag name
 * @param options element registration options
 * @returns Element registration decorator
 */
export const customElement = function (name, options = defaultOptions) {
    options = { ...defaultOptions, ...options };
    return (target) => {
        ElementRegistry.define(name, target);
        if (options.theme === false) {
            CustomStyleRegistry.define(name, '');
        }
    };
};
