/**
 * A directive used to map template attributes, properties and events to element
 */
import { noChange } from 'lit';
import { Directive, DirectiveResult, ElementPart, PartInfo } from 'lit/directive.js';
type TemplateMap = {
    [key: string]: unknown;
};
declare class TemplateMapDirective extends Directive {
    private valueMap;
    constructor(partInfo: PartInfo);
    /**
     * @param part Element part
     * @param attributeMap Attribute map
     * @returns noChange
     */
    update(part: ElementPart, [attributeMap]: [TemplateMap]): typeof noChange;
    /**
     * @returns noChange
     */
    render(): typeof noChange;
}
/**
 * A directive to apply attributes to template element
 * @param template Template map with the following syntax:
 * {
 *   'label': 'value', // set attribute with attribute value, e.g. `<input label="value">`
 *   'required': true, // set empty attribute, e.g. `<input required>`
 *   'error': null | undefined | false, // remove attribute `error`
 *   '.prop': 'value', // set property `.prop='value'`
 *   '.warning': undefined, // remove property `warning`
 *   '@listener': this.eventListener, // set event listener via element.addEventListener('listener', this.eventListener.bind(this)),
 *   '@changed': undefined // remove event listener `changed`
 * }
 * @returns noChange directive result
 */
declare const templateMap: (template: TemplateMap) => DirectiveResult<typeof TemplateMapDirective>;
export { templateMap };
export type { TemplateMapDirective, TemplateMap };
