import { BasicElement } from './BasicElement.js';
export type ElementSize = {
    width: number;
    height: number;
};
/**
 * @event resize
 * Dispatched when the content changes its size
 */
export type ResizeEvent = CustomEvent<{
    /**
     * New width of the element
     */
    width: number;
    /**
     * New height of the element
     */
    height: number;
}>;
/**
 * Responsive element base class.
 * Used for creating elements that need to
 * be aware of their dimensions. Data-viz, charts, grids, etc.
 */
export declare abstract class ResponsiveElement extends BasicElement {
    /**
     * Called when the element has been appended to the DOM
     * @returns {void}
     */
    connectedCallback(): void;
    /**
     * Called when the element has been removed from the DOM
     * @returns {void}
     */
    disconnectedCallback(): void;
    /**
     * Called when the element's dimensions have changed
     * @param size dimension details
     * @returns {void}
     */
    resizedCallback(size: ElementSize): void;
}
