import { MESSAGE_TYPE } from './constants.js';
const generateMessage = (type, message, supportURL) => `${type} notice:\n${!supportURL ? message : `${message}\n\n${supportURL}\n`}`;
/**
 * **Notice**\
 * Used to show notices in the console.
 */
export class Notice {
    /**
     * Create a warning notice to show in the console.
     * @param message Warning message to show in the console
     * @param supportURL Support URL to show additional information
     * @param type Type of Notice to show at top of message
     */
    constructor(message, supportURL, type = MESSAGE_TYPE.NOTICE) {
        /**
         * Flag used to check whether the notice has
         * already been shown in the console.
         */
        this.shown = false;
        this.message = generateMessage(type, message, supportURL);
    }
    /**
     * Shows the warning notice in the console
     * @returns {void}
     */
    show() {
        /* eslint-disable-next-line no-console */
        console.info(this.message);
        this.shown = true;
    }
    /**
     * Shows the warning notice only once
     * @returns {void}
     */
    once() {
        if (!this.shown) {
            this.show();
        }
    }
}
