import { DuplicateStyleError } from '../errors/DuplicateStyleError.js';
import { ready } from '../utils/elementReady.js';
import { isLocalhost } from '../utils/helpers.js';
const register = new Map();
/**
 * Custom Style Registry takes theme styles
 * and applies them to elements when they are defined.
 */
export class CustomStyleRegistry {
    /**
     * Define a style definition for a custom element.
     * @param name tag name of the custom element
     * @param css css style string
     * @returns {void}
     */
    static define(name, css) {
        if (register.has(name)) {
            if (isLocalhost) {
                throw new DuplicateStyleError(name);
            }
            /* c8 ignore start */
            return;
            /* c8 ignore stop */
        }
        register.set(name, css);
        ready(name);
    }
    /**
     * Gets any custom style that has already been defined.
     * @param name tag name of the custom element
     * @returns css styles, based on the tag name
     */
    static get(name) {
        return register.get(name) || '';
    }
}
