import type { ElementConstructor } from '../interfaces/ElementConstructor';
declare class ElementRegistrationItem {
    creations: number;
    connections: number;
    disconnections: number;
    version: string;
    constructor(definition: ElementConstructor);
}
export declare abstract class ElementRegistry {
    /**
     * Define a new custom element into the registry.
     * @param name tag name of the custom element
     * @param definition the class definition of the element
     * @param [options] element definition parameters
     * @returns {void}
     */
    static define(name: string, definition: ElementConstructor): void;
    /**
     * Gets the definition of an already defined custom element.
     * @param name tag name of the custom element
     * @returns Element registration object, or, `undefined`,
     * when there is no item registered by the provided name.
     */
    static get(name: string): ElementRegistrationItem | undefined;
    /**
     * Logs the creation of an element
     * @param element Element to register the creation of
     * @returns {void}
     */
    static create(element: HTMLElement): void;
    /**
     * Logs the connection of an element
     * @param element Element to register the connection of
     * @returns {void}
     */
    static connect(element: HTMLElement): void;
    /**
     * Logs the disconnection of an element
     * @param element Element to register the disconnection of
     * @returns {void}
     */
    static disconnect(element: HTMLElement): void;
}
export {};
