import { DuplicateStyleError } from '../errors/DuplicateStyleError.js';
import { isLocalhost } from '../utils/helpers.js';
const register = new Map();
/**
 * Native Style Registry takes theme styles
 * for standard HTML elements and applies these to the document.
 */
export class NativeStyleRegistry {
    /**
     * Defines a style definition for a native element.
     * @param name tag name of the element
     * @param css css styles for the element
     * @returns {void}
     */
    static define(name, css) {
        if (register.has(name)) {
            if (isLocalhost) {
                throw new DuplicateStyleError(name);
            }
            /* c8 ignore start */
            return;
            /* c8 ignore stop */
        }
        register.set(name, css);
        // Skip if style has empty content
        if (!css) {
            return;
        }
        const head = document.head;
        const childRef = head.firstElementChild;
        const style = document.createElement('style');
        style.setAttribute('scope', name);
        style.textContent = css;
        childRef ? head.insertBefore(style, childRef) : head.appendChild(style);
    }
    /**
     * Gets any native style that has already been defined.
     * @param name tag name of the element
     * @returns css styles, based on the tag name
     */
    static get(name) {
        return register.get(name) || '';
    }
}
